@@ -75,6 +75,21 @@ def test_no_remove_dataclass():
 
     source = '''
 @dataclass
+class MyClass:
+    myfield: int
+    mysecondfile: str
+
+@dataclasses.dataclass
+class MyClass:
+    myfield: int
+    mysecondfile: str
+
+@dataclass(frozen=True)
+class MyClass:
+    myfield: int
+    mysecondfile: str
+
+@dataclasses.dataclass(frozen=True)
 class MyClass:
     myfield: int
     mysecondfile: str
